@@ -40,4 +40,4 @@ class ParserError(Exception):  # ToDo: currently blank lines skipped thus printe
         self.msg = msg
 
     def __str__(self):
-        return f"{self.line + 1}:{self.pos}: {self.msg}"
+        return f"{self.line + 1}:{self.pos + 1}: {self.msg}"
